<?php

namespace Classifieds\Subcategory\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Classifieds\Subcategory\Actions\SubcategoryAction;
use Classifieds\Subcategory\Http\Requests\SubcategoryActionRequest;
use Classifieds\Subcategory\Http\Resources\SubcategoryResource;
use Classifieds\Subcategory\Models\Subcategory;

/**
 * Admin web controller class.
 */
class SubcategoryActionController extends BaseController
{

    /**
     * Action controller function for subcategory.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(SubcategoryActionRequest $request, Subcategory $subcategory, $action)
    {
        try {
            $request = $request->all();
            $subcategory = SubcategoryAction::run($action, $subcategory, $request);

            $data = new SubcategoryResource($subcategory);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('subcategory::subcategory.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('subcategory/subcategory/' . $subcategory->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('subcategory/subcategory/' . $subcategory->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
