<?php

namespace Classifieds\Subcategory\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Classifieds\Subcategory\Http\Resources\SubcategoryResource;
use Classifieds\Subcategory\Http\Resources\SubcategoriesCollection;
use Classifieds\Subcategory\Scopes\SubcategoryPublicScope;
use Classifieds\Subcategory\Models\Subcategory;

class SubcategoryPublicController extends BaseController
{

    /**
     * Show subcategory's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Subcategory::pushScope(new RequestScope())
            ->pushScope(new SubcategoryPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $subcategories = new SubcategoriesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('subcategory::subcategory.names'))
            ->view('subcategory::public.subcategory.index')
            ->data(compact('subcategories', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show subcategory.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Subcategory::findBySlug($slug);
        $data = new SubcategoryResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('subcategory::subcategory.name'))
            ->view('subcategory::public.subcategory.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
