<?php

namespace Classifieds\Subcategory\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Subcategory\Events\SubcategoryAction as SubcategoryActionEvent;
use Classifieds\Subcategory\Notifications\SubcategoryAction as SubcategoryActionNotification;
use Litepie\Actions\Concerns\AsAction;

class SubcategoryAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the SubcategoryActionEvent.
     *
     * @param   SubcategoryActionEvent  $event
     * @return mixed
     */
    public function handle(SubcategoryActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $subcategory.
     *
     * @param   SubcategoryActionEvent  $event
     * @return void
     */
    public function create(SubcategoryActionEvent $event)
    {
        $client = $event->subcategory->client;
        Notification::send($client, new SubcategoryActionNotification($event));
    }

    /**
     * Handle the SubcategoryActionEvent as a listener.
     *
     * @param   SubcategoryActionEvent  $event
     * @return mixed
     */
    public function asListener(SubcategoryActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   SubcategoryActionEvent  $event
     * @return bool
     */
    private function isAllowed(SubcategoryActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
