<?php

namespace Classifieds\Subcategory\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Subcategory\Events\SubcategoryWorkflow as SubcategoryWorkflowEvent;
use Classifieds\Subcategory\Notifications\SubcategoryWorkflow as SubcategoryWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class SubcategoryWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(SubcategoryWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $subcategory is submitted.
     *
     * @param SubcategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(SubcategoryWorkflowEvent $event)
    {
        $client = $event->subcategory->client;
        Notification::send($client, new SubcategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $subcategory is published.
     *
     * @param SubcategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(SubcategoryWorkflowEvent $event)
    {
        $client = $event->subcategory->client;
        Notification::send($client, new SubcategoryWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $subcategory is approved.
     *
     * @param SubcategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(SubcategoryWorkflowEvent $event)
    {
        $client = $event->subcategory->client;
        Notification::send($client, new SubcategoryWorkflowNotification($event));
    }

    /**
     * Handles the $subcategory workflow event as a listener.
     *
     * @param SubcategoryWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(SubcategoryWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
