<?php

namespace Classifieds\Subcategory\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Classifieds\Subcategory\Models\Subcategory;

class SubcategoryPolicy
{

    use SubcategoryAction;
    use SubcategoryWorkflow;

    /**
     * Determine if the given user can view the subcategory.
     *
     * @param Authenticatable $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function view(Authenticatable $user, Subcategory $subcategory)
    {
        if ($authUser->canDo('subcategory.subcategory.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $subcategory->is_owner;
    }

    /**
     * Determine if the given user can create a subcategory.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('subcategory.subcategory.create');
    }

    /**
     * Determine if the given user can update the given subcategory.
     *
     * @param Authenticatable $user
     * @param Subcategory $subcategory
     *
     * @return bool
     */
    public function update(Authenticatable $user, Subcategory $subcategory)
    {
        if ($user->canDo('subcategory.subcategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $subcategory->is_owner;
    }

    /**
     * Determine if the given user can delete the given subcategory.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Subcategory $subcategory)
    {
        return $subcategory->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
